==> r2r-3.1.40-py3-none-any.whl: core/base/providers/__init__.py <==
from .auth import AuthConfig, AuthProvider
from .base import Provider, ProviderConfig
from .chunking import (
    ChunkingConfig,
    ChunkingProvider,
    R2RChunkingConfig,
    Strategy,
    UnstructuredChunkingConfig,
)
from .crypto import CryptoConfig, CryptoProvider
from .database import (
    DatabaseConfig,
    DatabaseProvider,
    RelationalDBProvider,
    VectorDBProvider,
)
from .embedding import EmbeddingConfig, EmbeddingProvider
from .file import FileConfig, FileProvider
from .kg import KGConfig, KGProvider
from .llm import CompletionConfig, CompletionProvider
from .orchestration import OrchestrationConfig, OrchestrationProvider
from .parsing import OverrideParser, ParsingConfig, ParsingProvider
from .prompt import PromptConfig, PromptProvider

__all__ = [
    # Base provider classes
    "Provider",
    "ProviderConfig",
    # Auth provider
    "AuthConfig",
    "AuthProvider",
    # Chunking provider
    "UnstructuredChunkingConfig",
    "ChunkingConfig",
    "R2RChunkingConfig",
    "ChunkingProvider",
    "Strategy",
    # Crypto provider
    "CryptoConfig",
    "CryptoProvider",
    # Database providers
    "DatabaseConfig",
    "DatabaseProvider",
    "RelationalDBProvider",
    "VectorDBProvider",
    # Embedding provider
    "EmbeddingConfig",
    "EmbeddingProvider",
    # Knowledge Graph provider
    "KGConfig",
    "KGProvider",
    # LLM provider
    "CompletionConfig",
    "CompletionProvider",
    # Orchestration provider
    "OrchestrationConfig",
    "OrchestrationProvider",
    # Parsing provider
    "ParsingConfig",
    "ParsingProvider",
    "OverrideParser",
    # Prompt provider
    "PromptConfig",
    "PromptProvider",
    # File provider
    "FileConfig",
    "FileProvider",
]

==> r2r-3.2.32-py3-none-any.whl: core/base/providers/__init__.py <==
from .auth import AuthConfig, AuthProvider
from .base import AppConfig, Provider, ProviderConfig
from .crypto import CryptoConfig, CryptoProvider
from .database import (
    CollectionHandler,
    DatabaseConfig,
    DatabaseConnectionManager,
    DatabaseProvider,
    DocumentHandler,
    PostgresConfigurationSettings,
    TokenHandler,
    UserHandler,
    VectorHandler,
)
from .embedding import EmbeddingConfig, EmbeddingProvider
from .file import FileConfig, FileProvider
from .ingestion import ChunkingStrategy, IngestionConfig, IngestionProvider
from .kg import KGConfig, KGProvider
from .llm import CompletionConfig, CompletionProvider
from .orchestration import OrchestrationConfig, OrchestrationProvider, Workflow
from .prompt import PromptConfig, PromptProvider

__all__ = [
    # Auth provider
    "AuthConfig",
    "AuthProvider",
    # Base provider classes
    "AppConfig",
    "Provider",
    "ProviderConfig",
    # Ingestion provider
    "IngestionConfig",
    "IngestionProvider",
    "ChunkingStrategy",
    # Crypto provider
    "CryptoConfig",
    "CryptoProvider",
    # Database providers
    "DatabaseConnectionManager",
    "DocumentHandler",
    "CollectionHandler",
    "TokenHandler",
    "UserHandler",
    "VectorHandler",
    "DatabaseConfig",
    "PostgresConfigurationSettings",
    "DatabaseProvider",
    # Embedding provider
    "EmbeddingConfig",
    "EmbeddingProvider",
    # Knowledge Graph provider
    "KGConfig",
    "KGProvider",
    # LLM provider
    "CompletionConfig",
    "CompletionProvider",
    # Orchestration provider
    "OrchestrationConfig",
    "OrchestrationProvider",
    "Workflow",
    # Prompt provider
    "PromptConfig",
    "PromptProvider",
    # File provider
    "FileConfig",
    "FileProvider",
]
